/*
 * @System Call: 
 * 	jQuery(selector).watermark(Text, Class)
 * 		where:
 * 			Text 	-- The Text to be displayed as Watermark
 * 			Class -- a custom CSS class that can be used to control the look of the
 * 						watermark
 * 
 * @Synopsis:
 * 	This Plugin displays a fake watermark (fake as in "looks like one, but
 * 	isn't one"). Is uses standard text rather than an image, which is more
 * 	conveniant for quick and uncomplicated use. The look of the watermark can
 * 	be changed with the Class parameter.
 * 
 * @Author: 
 * 	Ferreira Esteves Mike
 * 	http://sulfura3.blogspot.com
 * 	sulfura3@gmail.com
 * 
 * @Info:
 * 	Please send any suggestions you might have to sulfura3+jquery@gmail.com
 * 	as I have a filter set on it.
 */


/*
 * Initializing the input field for first use
 */
jQuery.fn.extend({
	
	watermark: function(pText, pClass) {
		jQuery(this).bind('blur',function(){
			__watermark__blurEvent(this, pText, pClass);
		});
		jQuery(this).parents('form').bind('submit',function(){
			__watermark__submitEvent(this, pText, pClass);
		});
		if (jQuery(this).val() == '') {
			__watermark__setWatermark(this, pText, pClass);
			jQuery(this).bind('focus',function(){
				__watermark__focusEvent(this, pText, pClass);
			});
		}
		return this; 
	},	
});


/*
 * Sets the input value to the watermark Text and adds the watermark class.
 * Also, the cursor type is set to default for a more clean and neat look which
 * helps in creating the illusion of a real watermark
 */
function __watermark__setWatermark(pElement, pText, pClass) {
	jQuery(pElement).addClass(pClass);
	jQuery(pElement).css({'cursor':'default'});
	jQuery(pElement).val(pText);
}

/*
 * Removes the Text and Class of the Watermark, usually used when a User clicks
 * on the input field to use it.
 */
function __watermark__removerWatermark(pElement, pText, pClass) {
	pElement.value = '';
	jQuery(pElement).css({'cursor': 'text'});
	jQuery(pElement).removeClass(pClass);
}

/*
 * When a user clicks on the input field, we have to make sure that the
 * watermark vanished into thin air, as it must not interfere with the basic
 * form functionality. Next we unbind the focus event as 90% of the time,
 * the input field is filled with content after click and we don't want
 * to delete the real content on focus.
 */
function __watermark__focusEvent(pElement, pText, pClass) {
	__watermark__removerWatermark(pElement, pText, pClass);
	jQuery(pElement).unbind('focus');
}

/*
 * When the User leaves the input field, we check for no content or if the
 * control still has the watermark class. In both Cases, we assume there is
 * no usable content in the field and we re-apply the watermark and re-bind
 * the onFocus Event.
 */
function __watermark__blurEvent(pElement, pText, pClass) {
	if (pElement.value == '' || jQuery(pElement).hasClass(pClass)) {
		__watermark__setWatermark(pElement, pText, pClass);
		jQuery(pElement).bind('focus', function(){
			__watermark__focusEvent(pElement, pText, pClass);
		});
	};
}

/*
 * This is something the watermark usually doesn't have to care about. But since
 * we use a fake Watermark (ergo. we use the value of the field as watermark
 * text rather than a background image). We have to make sure that every input
 * field, which by the time of the submit still has the Watermark Class, is
 * stripped from its content, so that it doesn't interfere with the normal form
 * functionality. 
 */
function __watermark__submitEvent(pElement, pText, pClass) {
	jQuery('.' + pClass).val('');
}
